@@ -21,7 +21,6 @@ OTHER DEALINGS IN THE SOFTWARE.
 ============================================================================*/
 
 
-#if(IGFX_GEN >= IGFX_GEN10)
 
 #include "Internal/Common/GmmLibInc.h"
 #include "Internal/Common/Platform/GmmGen10Platform.h"
@@ -508,5 +507,10 @@ GmmLib::PlatformInfoGen10::PlatformInfoGen10(PLATFORM &Platform)
     Data.SurfaceMaxSize                      = GMM_GBYTE(256);
     Data.MaxGpuVirtualAddressBitsPerResource = 38;
     Data.HiZPixelsPerByte                    = 2;
+
+    Data.ReconMaxHeight = Data.Texture2DSurface.MaxHeight; // Reconstructed surfaces require more height and width for higher resolutions.
+    Data.ReconMaxWidth  = Data.Texture2DSurface.MaxWidth;
+
+    Data.NoOfBitsSupported                = 39;
+    Data.HighestAcceptablePhysicalAddress = GFX_MASK_LARGE(0, 38);
 }
-#endif // #if (IGFX_GEN >= IGFX_GEN10)
