@@ -30,6 +30,8 @@ OTHER DEALINGS IN THE SOFTWARE.
 
     #if defined(_WIN64)
         #define GMM_UMD_DLL           "igdgmm64.dll"
+    #elif defined(ANDROID)
+        #define GMM_UMD_DLL           "libigdgmm.so"
     #else
         #define GMM_UMD_DLL           "libigdgmm.so.11"
     #endif
@@ -42,6 +44,8 @@ OTHER DEALINGS IN THE SOFTWARE.
 
     #if defined(_WIN32)
         #define GMM_UMD_DLL     "igdgmm32.dll"
+    #elif defined(ANDROID)
+        #define GMM_UMD_DLL     "libigdgmm.so"
     #else
         #define GMM_UMD_DLL     "libigdgmm.so.11"
     #endif
